@@ -14,7 +14,7 @@ DRBL_SCRIPT_PATH="${DRBL_SCRIPT_PATH:-/opt/drbl/}"
 . $DRBL_SCRIPT_PATH/sbin/drbl-conf-functions
 
 # Settings
-SL_ISO_URL_EXAMPLE="http://prdownloads.sourceforge.net/clonezilla/clonezilla-live-1.2.5-6-i686.iso"
+SL_ISO_URL_EXAMPLE="http://downloads.sourceforge.net/clonezilla/clonezilla-live-1.2.6-24-i686.iso"
 # The method for netboot's root file system. "fetch" means the client will download the filesystem.squashfs from tftpd server, "nfsroot" means client will mount the nfs server. By default we use fetch. "nfsroot" only works for Debian-live based system (e.g. Clonezilla live, GParted live...)
 rootfs_location="fetch"
 # Force to update the PXELinux config file
