@@ -156,6 +156,10 @@ case "$switch" in
        fi
      fi
 
+     # ocs_client_no_per_NIC is read from /etc/ocs/ocs-live.conf, which might be from boot parameter.
+     if [ -n "$ocs_client_no_per_NIC" ]; then
+       LC_ALL=C perl -pi -e "s/^client_no_per_NIC=.*/client_no_per_NIC=$ocs_client_no_per_NIC/g" $drbl_setup_path/files/ocs/live-hook/ocs-live-hook.conf
+     fi
      # load $client_no_per_NIC and $autologin_passwd_opt for later use
      . $drbl_setup_path/files/ocs/live-hook/ocs-live-hook.conf
 
